//+-----------------------------------------------------------------------+
//|                                                   ConservativeAnt.mq4 |
//|                                             Created by Nick and Chris |
//|                         Original idea comes from Renato P. dos Santos |
//|                                    Renato's website is www.reniza.com |
//+-----------------------------------------------------------------------+
#property copyright "Copyright  2006, Nick and Chris"   

//Input variable that can be edited by the user when testing
//These varieable are those found under the input tab when looking at the EA's properties

extern string other_parameters   = "-------- Execution Management --------"; //heading
extern int stoploss              = 8;  //This is your user defined s/l
extern int takeprofit            = 8;  //This is your user defined t/p
extern int barspread             = 10; //How much the bar has to spread apart before a trade will execute
extern int max_trades            = 1;  //Max number of trades that can be executed at any one given time
extern int max_barspread         = 30; //Max the bar can be spread and a trade still made
extern string  mm_parameters     = "---------- Money Management ----------";//Just a heading
extern bool money_management     = false; //Use Money Management or not
extern double lots               = 1;  //Number of lots to use.  It will increase lots with increased margin
extern int risk                  = 10; //How much margin to risk 10%. Total risk is determined by your s/l
extern string scalping_control   = "-------- Scalping Control ------------";
extern bool scalp_control        = true; //Use Scalping Control or not.
extern double min_time           = 4;  //Minimum minutes before trade can Close
extern double leeway             = 60;  //The temporary ADDITIONAL (on top of sl, tp) min_time leeway. 
extern string methodology        = "-----Aggresive Methodology???-----"; //Set which method to use classic or aggresive
extern bool aggresive_method     = true;   

int summary = 0;
//A global variable but not one what can be manually changed in under the EA's properties
int ID=983783;         

int init() {return(0);}
int deinit() {return(0);}

//Figure out how many lots to use
int subLotSize()
   {
   int lotMM = MathCeil(AccountFreeMargin() *  risk / 1000) / 100;
	   if(lotMM < 0.1)                  lotMM = lots;
	   if((lotMM > 0.5) && (lotMM < 1)) lotMM = lots;
	   if(lotMM > 1)                    lotMM = MathCeil(lotMM);
	   if(lotMM > 100)                  lotMM = 100;
	return (lotMM);
   }
  
int start()
  {
     
   double sl,tp,ticket,cnt,scalp_gap,minimum_minutes; //Variable that will be used to store sl and tp data
   int total_orders = OrdersTotal();
   //if (Period() < 30) {Comment("change to M30 or higher pls"); return(0); }      
   
   if(money_management)lots = subLotSize(); //If MM is true then execute the MM function to increase lots with increasing margin
   if(scalp_control)
   {
      minimum_minutes = min_time;
      scalp_gap = leeway;  // Sets the minimum time before a trade can execute
   } 
   //if (MathMod(Minute(),Period()) >= 0.5*Period()) return(0);  I have no idea what this was originally for
   
   //Summary of setup
   if (summary ==0){summary++;
      Print("Hello summary");}

   //If bar/candle has moved more than 10 pips in this time frame and if the open is less than the
   //average of the high and the low and at the current moment the ask is less than the open, go long
   if (total_orders < max_trades)
   {
      
      //This is the aggressive method of entering a trade
      if(aggresive_method)
      {  
         
         if ( (High[0]-Low[0]) > barspread*Point && Bid == Low[0] && (High[0]-Low[0]) < max_barspread*Point)
         {
            if(stoploss==0){sl=0;}else{sl=Ask-stoploss*Point-scalp_gap*Point;} 
            if(takeprofit==0){tp=0;}else{tp=Ask+takeprofit*Point+scalp_gap*Point;}
            ticket=OrderSend(Symbol(),OP_BUY,lots,Ask,2,sl,tp,"ConservativeAntAggressiveBuy",ID,0,Blue);
            Print("Ticket # ",ticket);
            if(ticket>0){if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES))
            Print("Buy opened : ", OrderOpenPrice(), " at time ",OrderOpenTime(), "Ask ",Ask," Bid ",Bid);}
         }
   
      
      //If bar/candle has moved more than 10 pips in this time frame and if the open is greater than the
      //average of the high and the low and at the current moment the Bid is greater than the open, go short
      
         if ((High[0]-Low[0])>barspread*Point && Bid == High[0] && (High[0]-Low[0]) < max_barspread*Point)
         {
            if(stoploss==0){sl=0;}else{sl=Bid+stoploss*Point+scalp_gap*Point;}
            if(takeprofit==0){tp=0;}else{tp=Bid-takeprofit*Point-scalp_gap*Point;}
            ticket=OrderSend(Symbol(),OP_SELL,lots,Bid,2,sl,tp,"ConservativeAntAggressiveSell",ID,0,Green);
            Print("Ticket # ",ticket); 
            if(ticket>0){if(OrderSelect(ticket,SELECT_BY_TICKET,MODE_TRADES))
            Print("Sell opened : ", OrderOpenPrice(), " at time ",OrderOpenTime(), "Ask ",Ask," Bid ",Bid);}
         }
      }
   
      //This is the classic method of entering a trade
      if(aggresive_method == false)
      {
         
         if ( (High[0]-Low[0]) > barspread*Point && Open[0] < ((High[0]+Low[0])/2) && Ask < Open[0])
         {
            if(stoploss==0){sl=0;}else{sl=Ask-stoploss*Point-scalp_gap*Point;} 
            if(takeprofit==0){tp=0;}else{tp=Ask+takeprofit*Point+scalp_gap*Point;}
            ticket=OrderSend(Symbol(),OP_BUY,lots,Ask,2,sl,tp,"ConservativeAntClassicBuy",ID,0,Blue);
            Print("Ticket # ",ticket);
         }
                   
         if ((High[0]-Low[0])>barspread*Point && Open[0] > ((High[0]+Low[0])/2) && Bid > Open[0])
         {
            if(stoploss==0){sl=0;}else{sl=Bid+stoploss*Point+scalp_gap*Point;}
            if(takeprofit==0){tp=0;}else{tp=Bid-takeprofit*Point-scalp_gap*Point;}
            ticket=OrderSend(Symbol(),OP_SELL,lots,Bid,2,sl,tp,"ConservativeAntClassicSell",ID,0,Green);
            Print("Ticket # ",ticket); 
         }
      }
   }
      
      //Modifying existing orders. 
   for(cnt=0;cnt<total_orders;cnt++)  //This will cycle through each existing order.
   {
      OrderSelect(cnt,SELECT_BY_POS,MODE_TRADES);  //Selects the order by index and if it is active.
         if(OrderType()<=OP_SELL && OrderSymbol()==Symbol())  //Checks to insure normal order is for expert's chart.
         {
            //Print(OrderOpenTime(),"OrderOpenTime ",TimeMinute(OrderOpenTime()), "TimeMinute ", CurTime(), "CurTime");
            //Print("Time parameter is true: ",OrderOpenTime(),"  ",(OrderOpenTime()+min_time*60));   
            if(/*SOMEKIND OF TIME PARAMETER*/ CurTime() >= OrderOpenTime()+min_time*60  )   //Time parameter to prevent scalping.
            { Print("True"); 
               if(OrderType()==OP_BUY)   //Selects buy orders.
               { 
                     if(stoploss==0){sl=0;}else{sl=OrderOpenPrice()-stoploss*Point;}       
                     if(takeprofit==0){tp=0;}else{tp=OrderOpenPrice()+takeprofit*Point;}
                     if(OrderStopLoss()!= sl)
                     {
                       if(Bid >= tp || Bid <= sl)
                       {
                          OrderClose(OrderTicket(),OrderLots(),Bid,2,Olive); //closes the order if after the scalp_gap the price is 
                       }                                                     //outside the tp or sl
                       else 
                       {
                          OrderModify(OrderTicket(),OrderOpenPrice(),sl,tp,0,Yellow); //modifies the order back to original 
                       }                                                              //parameters
                     }
               }
                  
               if(OrderType()==OP_SELL)  //Selects sell orders.
               {
                     if(stoploss==0){sl=0;}else{sl=OrderOpenPrice()+stoploss*Point;}       
                     if(takeprofit==0){tp=0;}else{tp=OrderOpenPrice()-takeprofit*Point;}
                     if(OrderStopLoss() != sl)
                     {
                       if(Ask <= tp || Ask >= sl)
                       {
                          OrderClose(OrderTicket(),OrderLots(),Ask,2,Teal); //closes the order if after the scalp_gap the price is
                       }                                                    //ouside the tp or sl
                       else
                       {
                          OrderModify(OrderTicket(),OrderOpenPrice(),sl,tp,0,Violet); //modifies the order back to original
                       }
                     }                                                                //parameters
                }
             }
            
         }
    }
      
    
   return(0);
  }




